# coding: utf-8

"""
    Marketing API

    <p>The <i>Marketing API </i> offers two platforms that sellers can use to promote and advertise their products:</p> <ul><li><b>Promoted Listings</b> is an eBay ad service that lets sellers set up <i>ad campaigns </i> for the products they want to promote. eBay displays the ads in search results and in other marketing modules as <b>SPONSORED</b> listings. If an item in a Promoted Listings campaign sells, the seller is assessed a Promoted Listings fee, which is a seller-specified percentage applied to the sales price. For complete details, refer to the <a href=\"/api-docs/sell/static/marketing/pl-landing.html\">Promoted Listings playbook</a>.</li><li><b>Promotions Manager</b> gives sellers a way to offer discounts on specific items as a way to attract buyers to their inventory. Sellers can set up discounts (such as \"20% off\" and other types of offers) on specific items or on an entire customer order. To further attract buyers, eBay prominently displays promotion <i>teasers</i> throughout buyer flows. For complete details, see <a href=\"/api-docs/sell/static/marketing/promotions-manager.html\">Promotions Manager</a>.</li></ul>  <p><b>Marketing reports</b>, on both the Promoted Listings and Promotions Manager platforms, give sellers information that shows the effectiveness of their marketing strategies. The data gives sellers the ability to review and fine tune their marketing efforts.</p><p><b>Store Email Campaign</b> allows sellers to create and send email campaigns to customers who have signed up to receive their newsletter. For more information on email campaigns, see <a href=\"/api-docs/sell/static/marketing/store-email-campaigns.html#email-campain-types\" target=\"_blank\">Store Email Campaigns</a>.<p class=\"tablenote\"><b>Important!</b> Sellers must have an active eBay Store subscription, and they must accept the <b>Terms and Conditions</b> before they can make requests to these APIs in the Production environment. There are also site-specific listings requirements and restrictions associated with these marketing tools, as listed in the \"requirements and restrictions\" sections for <a href=\"/api-docs/sell/marketing/static/overview.html#PL-requirements\">Promoted Listings</a> and <a href=\"/api-docs/sell/marketing/static/overview.html#PM-requirements\">Promotions Manager</a>.</p> <p>The table below lists all the Marketing API calls grouped by resource.</p>  # noqa: E501

    OpenAPI spec version: v1.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateAdGroupRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ad_group_status': 'str',
        'default_bid': 'Amount',
        'name': 'str'
    }

    attribute_map = {
        'ad_group_status': 'adGroupStatus',
        'default_bid': 'defaultBid',
        'name': 'name'
    }

    def __init__(self, ad_group_status=None, default_bid=None, name=None):  # noqa: E501
        """UpdateAdGroupRequest - a model defined in Swagger"""  # noqa: E501
        self._ad_group_status = None
        self._default_bid = None
        self._name = None
        self.discriminator = None
        if ad_group_status is not None:
            self.ad_group_status = ad_group_status
        if default_bid is not None:
            self.default_bid = default_bid
        if name is not None:
            self.name = name

    @property
    def ad_group_status(self):
        """Gets the ad_group_status of this UpdateAdGroupRequest.  # noqa: E501

        An enumeration value representing the current status of the ad group.<p>If the status of the ad is currently <code>ACTIVE</code>, you can change status to <code>PAUSED</code> or <code>ARCHIVED</code>. If ad group is currently in <code>PAUSED</code> status, you can change the status back to <code>ACTIVE</code>. Ads that are currently in <code>ARCHIVED</code> status cannot be made <code>ACTIVE</code> again.<br /><br /><b>Valid Values:</b><ul><li><code>ACTIVE</code></li><li><code>PAUSED</code></li><li><code>ARCHIVED</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:AdGroupStatusEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ad_group_status of this UpdateAdGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_status

    @ad_group_status.setter
    def ad_group_status(self, ad_group_status):
        """Sets the ad_group_status of this UpdateAdGroupRequest.

        An enumeration value representing the current status of the ad group.<p>If the status of the ad is currently <code>ACTIVE</code>, you can change status to <code>PAUSED</code> or <code>ARCHIVED</code>. If ad group is currently in <code>PAUSED</code> status, you can change the status back to <code>ACTIVE</code>. Ads that are currently in <code>ARCHIVED</code> status cannot be made <code>ACTIVE</code> again.<br /><br /><b>Valid Values:</b><ul><li><code>ACTIVE</code></li><li><code>PAUSED</code></li><li><code>ARCHIVED</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:AdGroupStatusEnum'>eBay API documentation</a>  # noqa: E501

        :param ad_group_status: The ad_group_status of this UpdateAdGroupRequest.  # noqa: E501
        :type: str
        """

        self._ad_group_status = ad_group_status

    @property
    def default_bid(self):
        """Gets the default_bid of this UpdateAdGroupRequest.  # noqa: E501


        :return: The default_bid of this UpdateAdGroupRequest.  # noqa: E501
        :rtype: Amount
        """
        return self._default_bid

    @default_bid.setter
    def default_bid(self, default_bid):
        """Sets the default_bid of this UpdateAdGroupRequest.


        :param default_bid: The default_bid of this UpdateAdGroupRequest.  # noqa: E501
        :type: Amount
        """

        self._default_bid = default_bid

    @property
    def name(self):
        """Gets the name of this UpdateAdGroupRequest.  # noqa: E501

        The updated name for the specified ad group.  # noqa: E501

        :return: The name of this UpdateAdGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateAdGroupRequest.

        The updated name for the specified ad group.  # noqa: E501

        :param name: The name of this UpdateAdGroupRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateAdGroupRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAdGroupRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateConsignPreferenceRequestData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'consign_preference_name': 'str',
        'dropoff_site_id': 'str',
        'pickup_address': 'PickupAddressRequestData',
        'pickup_time': 'str',
        'type': 'str'
    }

    attribute_map = {
        'consign_preference_name': 'consignPreferenceName',
        'dropoff_site_id': 'dropoffSiteId',
        'pickup_address': 'pickupAddress',
        'pickup_time': 'pickupTime',
        'type': 'type'
    }

    def __init__(self, consign_preference_name=None, dropoff_site_id=None, pickup_address=None, pickup_time=None, type=None):  # noqa: E501
        """CreateConsignPreferenceRequestData - a model defined in Swagger"""  # noqa: E501
        self._consign_preference_name = None
        self._dropoff_site_id = None
        self._pickup_address = None
        self._pickup_time = None
        self._type = None
        self.discriminator = None
        if consign_preference_name is not None:
            self.consign_preference_name = consign_preference_name
        if dropoff_site_id is not None:
            self.dropoff_site_id = dropoff_site_id
        if pickup_address is not None:
            self.pickup_address = pickup_address
        if pickup_time is not None:
            self.pickup_time = pickup_time
        if type is not None:
            self.type = type

    @property
    def consign_preference_name(self):
        """Gets the consign_preference_name of this CreateConsignPreferenceRequestData.  # noqa: E501

        The name of the consign address.  # noqa: E501

        :return: The consign_preference_name of this CreateConsignPreferenceRequestData.  # noqa: E501
        :rtype: str
        """
        return self._consign_preference_name

    @consign_preference_name.setter
    def consign_preference_name(self, consign_preference_name):
        """Sets the consign_preference_name of this CreateConsignPreferenceRequestData.

        The name of the consign address.  # noqa: E501

        :param consign_preference_name: The consign_preference_name of this CreateConsignPreferenceRequestData.  # noqa: E501
        :type: str
        """

        self._consign_preference_name = consign_preference_name

    @property
    def dropoff_site_id(self):
        """Gets the dropoff_site_id of this CreateConsignPreferenceRequestData.  # noqa: E501

        The unique identifier of a drop-off site location. This value can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/dropoff_sites/methods/getDropoffSites\" target=\"_blank\">getDropoffSites</a> method.<br><br>This field is required if the <code>DROPOFF</code> address type is specified.  # noqa: E501

        :return: The dropoff_site_id of this CreateConsignPreferenceRequestData.  # noqa: E501
        :rtype: str
        """
        return self._dropoff_site_id

    @dropoff_site_id.setter
    def dropoff_site_id(self, dropoff_site_id):
        """Sets the dropoff_site_id of this CreateConsignPreferenceRequestData.

        The unique identifier of a drop-off site location. This value can be retrieved using the <a href=\"/api-docs/sell/edelivery_international_shipping/resources/dropoff_sites/methods/getDropoffSites\" target=\"_blank\">getDropoffSites</a> method.<br><br>This field is required if the <code>DROPOFF</code> address type is specified.  # noqa: E501

        :param dropoff_site_id: The dropoff_site_id of this CreateConsignPreferenceRequestData.  # noqa: E501
        :type: str
        """

        self._dropoff_site_id = dropoff_site_id

    @property
    def pickup_address(self):
        """Gets the pickup_address of this CreateConsignPreferenceRequestData.  # noqa: E501


        :return: The pickup_address of this CreateConsignPreferenceRequestData.  # noqa: E501
        :rtype: PickupAddressRequestData
        """
        return self._pickup_address

    @pickup_address.setter
    def pickup_address(self, pickup_address):
        """Sets the pickup_address of this CreateConsignPreferenceRequestData.


        :param pickup_address: The pickup_address of this CreateConsignPreferenceRequestData.  # noqa: E501
        :type: PickupAddressRequestData
        """

        self._pickup_address = pickup_address

    @property
    def pickup_time(self):
        """Gets the pickup_time of this CreateConsignPreferenceRequestData.  # noqa: E501

        The pickup time that the pickup location supports.<br><br>This field is required if the <code>PICK_UP</code> address type is specified. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:PickUpTimeTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The pickup_time of this CreateConsignPreferenceRequestData.  # noqa: E501
        :rtype: str
        """
        return self._pickup_time

    @pickup_time.setter
    def pickup_time(self, pickup_time):
        """Sets the pickup_time of this CreateConsignPreferenceRequestData.

        The pickup time that the pickup location supports.<br><br>This field is required if the <code>PICK_UP</code> address type is specified. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:PickUpTimeTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param pickup_time: The pickup_time of this CreateConsignPreferenceRequestData.  # noqa: E501
        :type: str
        """

        self._pickup_time = pickup_time

    @property
    def type(self):
        """Gets the type of this CreateConsignPreferenceRequestData.  # noqa: E501

        The address type of the consign address.<br><br><b>Valid values</b>:<ul><li><code>PICK_UP</code></li><li><code>DROP_OFF</code></li><li><code>FORWARD_DEPLOYMENT</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:ConsignTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The type of this CreateConsignPreferenceRequestData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateConsignPreferenceRequestData.

        The address type of the consign address.<br><br><b>Valid values</b>:<ul><li><code>PICK_UP</code></li><li><code>DROP_OFF</code></li><li><code>FORWARD_DEPLOYMENT</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/edelivery_international_shipping/types/api:ConsignTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param type: The type of this CreateConsignPreferenceRequestData.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateConsignPreferenceRequestData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConsignPreferenceRequestData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Browse API

    The Browse API has the following resources:<ul><li><b>item_summary:</b><br>Allows shoppers to search for specific items by keyword, GTIN, category, charity, product, image, or item aspects and refine the results by using filters, such as aspects, compatibility, and fields values, or UI parameters.</li><li><b>item:</b><br>Allows shoppers to retrieve the details of a specific item or all items in an item group, which is an item with variations such as color and size and check if a product is compatible with the specified item, such as if a specific car is compatible with a specific part.<br><br>This resource also provides a bridge between the eBay legacy APIs, such as the <a href=\"/api-docs/user-guides/static/finding-user-guide-landing.html\" target=\"_blank\">Finding</b>, and the RESTful APIs, which use different formats for the item IDs.</li></ul>The <b>item_summary</b>, <b>search_by_image</b>, and <b>item</b> resource calls require an <a href=\"/api-docs/static/oauth-client-credentials-grant.html\" target=\"_blank\">Application access token</a>.  # noqa: E501

    OpenAPI spec version: v1.20.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReviewRating(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average_rating': 'str',
        'rating_histograms': 'list[RatingHistogram]',
        'review_count': 'int'
    }

    attribute_map = {
        'average_rating': 'averageRating',
        'rating_histograms': 'ratingHistograms',
        'review_count': 'reviewCount'
    }

    def __init__(self, average_rating=None, rating_histograms=None, review_count=None):  # noqa: E501
        """ReviewRating - a model defined in Swagger"""  # noqa: E501
        self._average_rating = None
        self._rating_histograms = None
        self._review_count = None
        self.discriminator = None
        if average_rating is not None:
            self.average_rating = average_rating
        if rating_histograms is not None:
            self.rating_histograms = rating_histograms
        if review_count is not None:
            self.review_count = review_count

    @property
    def average_rating(self):
        """Gets the average_rating of this ReviewRating.  # noqa: E501

        The average rating given to a product based on customer reviews.  # noqa: E501

        :return: The average_rating of this ReviewRating.  # noqa: E501
        :rtype: str
        """
        return self._average_rating

    @average_rating.setter
    def average_rating(self, average_rating):
        """Sets the average_rating of this ReviewRating.

        The average rating given to a product based on customer reviews.  # noqa: E501

        :param average_rating: The average_rating of this ReviewRating.  # noqa: E501
        :type: str
        """

        self._average_rating = average_rating

    @property
    def rating_histograms(self):
        """Gets the rating_histograms of this ReviewRating.  # noqa: E501

        An array of containers for the product rating histograms that shows the review counts and the product rating.  # noqa: E501

        :return: The rating_histograms of this ReviewRating.  # noqa: E501
        :rtype: list[RatingHistogram]
        """
        return self._rating_histograms

    @rating_histograms.setter
    def rating_histograms(self, rating_histograms):
        """Sets the rating_histograms of this ReviewRating.

        An array of containers for the product rating histograms that shows the review counts and the product rating.  # noqa: E501

        :param rating_histograms: The rating_histograms of this ReviewRating.  # noqa: E501
        :type: list[RatingHistogram]
        """

        self._rating_histograms = rating_histograms

    @property
    def review_count(self):
        """Gets the review_count of this ReviewRating.  # noqa: E501

        The total number of reviews for the item.  # noqa: E501

        :return: The review_count of this ReviewRating.  # noqa: E501
        :rtype: int
        """
        return self._review_count

    @review_count.setter
    def review_count(self, review_count):
        """Sets the review_count of this ReviewRating.

        The total number of reviews for the item.  # noqa: E501

        :param review_count: The review_count of this ReviewRating.  # noqa: E501
        :type: int
        """

        self._review_count = review_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReviewRating, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReviewRating):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ItemResponses(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'buyer_id': 'str',
        'buyer_tax_id': 'str',
        'buyer_tax_type': 'str',
        'ebay_collect_and_remit_tax': 'bool',
        'ebay_collect_and_remit_taxes_value': 'str',
        'email': 'str',
        'item_title': 'str',
        'listing_id': 'str',
        'message': 'str',
        'order_id': 'str',
        'order_line_item': 'str',
        'payment_date': 'str',
        'pay_pal_email': 'str',
        'pay_pal_message': 'str',
        'posted_quantity': 'int',
        'site_id': 'int',
        'sku': 'SkuRequest',
        'sold_date': 'str',
        'sold_price': 'Amount',
        'sold_quantity': 'int',
        'transaction_id': 'str'
    }

    attribute_map = {
        'buyer_id': 'buyerId',
        'buyer_tax_id': 'buyerTaxId',
        'buyer_tax_type': 'buyerTaxType',
        'ebay_collect_and_remit_tax': 'ebayCollectAndRemitTax',
        'ebay_collect_and_remit_taxes_value': 'ebayCollectAndRemitTaxesValue',
        'email': 'email',
        'item_title': 'itemTitle',
        'listing_id': 'listingId',
        'message': 'message',
        'order_id': 'orderId',
        'order_line_item': 'orderLineItem',
        'payment_date': 'paymentDate',
        'pay_pal_email': 'payPalEmail',
        'pay_pal_message': 'payPalMessage',
        'posted_quantity': 'postedQuantity',
        'site_id': 'siteId',
        'sku': 'sku',
        'sold_date': 'soldDate',
        'sold_price': 'soldPrice',
        'sold_quantity': 'soldQuantity',
        'transaction_id': 'transactionId'
    }

    def __init__(self, buyer_id=None, buyer_tax_id=None, buyer_tax_type=None, ebay_collect_and_remit_tax=None, ebay_collect_and_remit_taxes_value=None, email=None, item_title=None, listing_id=None, message=None, order_id=None, order_line_item=None, payment_date=None, pay_pal_email=None, pay_pal_message=None, posted_quantity=None, site_id=None, sku=None, sold_date=None, sold_price=None, sold_quantity=None, transaction_id=None):  # noqa: E501
        """ItemResponses - a model defined in Swagger"""  # noqa: E501
        self._buyer_id = None
        self._buyer_tax_id = None
        self._buyer_tax_type = None
        self._ebay_collect_and_remit_tax = None
        self._ebay_collect_and_remit_taxes_value = None
        self._email = None
        self._item_title = None
        self._listing_id = None
        self._message = None
        self._order_id = None
        self._order_line_item = None
        self._payment_date = None
        self._pay_pal_email = None
        self._pay_pal_message = None
        self._posted_quantity = None
        self._site_id = None
        self._sku = None
        self._sold_date = None
        self._sold_price = None
        self._sold_quantity = None
        self._transaction_id = None
        self.discriminator = None
        if buyer_id is not None:
            self.buyer_id = buyer_id
        if buyer_tax_id is not None:
            self.buyer_tax_id = buyer_tax_id
        if buyer_tax_type is not None:
            self.buyer_tax_type = buyer_tax_type
        if ebay_collect_and_remit_tax is not None:
            self.ebay_collect_and_remit_tax = ebay_collect_and_remit_tax
        if ebay_collect_and_remit_taxes_value is not None:
            self.ebay_collect_and_remit_taxes_value = ebay_collect_and_remit_taxes_value
        if email is not None:
            self.email = email
        if item_title is not None:
            self.item_title = item_title
        if listing_id is not None:
            self.listing_id = listing_id
        if message is not None:
            self.message = message
        if order_id is not None:
            self.order_id = order_id
        if order_line_item is not None:
            self.order_line_item = order_line_item
        if payment_date is not None:
            self.payment_date = payment_date
        if pay_pal_email is not None:
            self.pay_pal_email = pay_pal_email
        if pay_pal_message is not None:
            self.pay_pal_message = pay_pal_message
        if posted_quantity is not None:
            self.posted_quantity = posted_quantity
        if site_id is not None:
            self.site_id = site_id
        if sku is not None:
            self.sku = sku
        if sold_date is not None:
            self.sold_date = sold_date
        if sold_price is not None:
            self.sold_price = sold_price
        if sold_quantity is not None:
            self.sold_quantity = sold_quantity
        if transaction_id is not None:
            self.transaction_id = transaction_id

    @property
    def buyer_id(self):
        """Gets the buyer_id of this ItemResponses.  # noqa: E501

        The buyer's eBay ID.  # noqa: E501

        :return: The buyer_id of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, buyer_id):
        """Sets the buyer_id of this ItemResponses.

        The buyer's eBay ID.  # noqa: E501

        :param buyer_id: The buyer_id of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._buyer_id = buyer_id

    @property
    def buyer_tax_id(self):
        """Gets the buyer_tax_id of this ItemResponses.  # noqa: E501

        The buyer's tax ID.  # noqa: E501

        :return: The buyer_tax_id of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._buyer_tax_id

    @buyer_tax_id.setter
    def buyer_tax_id(self, buyer_tax_id):
        """Sets the buyer_tax_id of this ItemResponses.

        The buyer's tax ID.  # noqa: E501

        :param buyer_tax_id: The buyer_tax_id of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._buyer_tax_id = buyer_tax_id

    @property
    def buyer_tax_type(self):
        """Gets the buyer_tax_type of this ItemResponses.  # noqa: E501

        The buyer's tax type.  # noqa: E501

        :return: The buyer_tax_type of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._buyer_tax_type

    @buyer_tax_type.setter
    def buyer_tax_type(self, buyer_tax_type):
        """Sets the buyer_tax_type of this ItemResponses.

        The buyer's tax type.  # noqa: E501

        :param buyer_tax_type: The buyer_tax_type of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._buyer_tax_type = buyer_tax_type

    @property
    def ebay_collect_and_remit_tax(self):
        """Gets the ebay_collect_and_remit_tax of this ItemResponses.  # noqa: E501

        If returned as <code>true</code>, this boolean indicates that eBay will collect tax for the corresponding line item, and remit the tax to the taxing authority of the buyer's residence.   # noqa: E501

        :return: The ebay_collect_and_remit_tax of this ItemResponses.  # noqa: E501
        :rtype: bool
        """
        return self._ebay_collect_and_remit_tax

    @ebay_collect_and_remit_tax.setter
    def ebay_collect_and_remit_tax(self, ebay_collect_and_remit_tax):
        """Sets the ebay_collect_and_remit_tax of this ItemResponses.

        If returned as <code>true</code>, this boolean indicates that eBay will collect tax for the corresponding line item, and remit the tax to the taxing authority of the buyer's residence.   # noqa: E501

        :param ebay_collect_and_remit_tax: The ebay_collect_and_remit_tax of this ItemResponses.  # noqa: E501
        :type: bool
        """

        self._ebay_collect_and_remit_tax = ebay_collect_and_remit_tax

    @property
    def ebay_collect_and_remit_taxes_value(self):
        """Gets the ebay_collect_and_remit_taxes_value of this ItemResponses.  # noqa: E501

        The value of the collect and remit tax for the corresponding line item. This field is only returned if collect and remit tax is applied to the line item.   # noqa: E501

        :return: The ebay_collect_and_remit_taxes_value of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._ebay_collect_and_remit_taxes_value

    @ebay_collect_and_remit_taxes_value.setter
    def ebay_collect_and_remit_taxes_value(self, ebay_collect_and_remit_taxes_value):
        """Sets the ebay_collect_and_remit_taxes_value of this ItemResponses.

        The value of the collect and remit tax for the corresponding line item. This field is only returned if collect and remit tax is applied to the line item.   # noqa: E501

        :param ebay_collect_and_remit_taxes_value: The ebay_collect_and_remit_taxes_value of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._ebay_collect_and_remit_taxes_value = ebay_collect_and_remit_taxes_value

    @property
    def email(self):
        """Gets the email of this ItemResponses.  # noqa: E501

        The buyer's eBay email address.  # noqa: E501

        :return: The email of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ItemResponses.

        The buyer's eBay email address.  # noqa: E501

        :param email: The email of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def item_title(self):
        """Gets the item_title of this ItemResponses.  # noqa: E501

        The seller created title of the item.  # noqa: E501

        :return: The item_title of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._item_title

    @item_title.setter
    def item_title(self, item_title):
        """Sets the item_title of this ItemResponses.

        The seller created title of the item.  # noqa: E501

        :param item_title: The item_title of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._item_title = item_title

    @property
    def listing_id(self):
        """Gets the listing_id of this ItemResponses.  # noqa: E501

        The unique identifier of the eBay listing associated with the item.  # noqa: E501

        :return: The listing_id of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """Sets the listing_id of this ItemResponses.

        The unique identifier of the eBay listing associated with the item.  # noqa: E501

        :param listing_id: The listing_id of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._listing_id = listing_id

    @property
    def message(self):
        """Gets the message of this ItemResponses.  # noqa: E501

        The buyer's eBay message.  # noqa: E501

        :return: The message of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ItemResponses.

        The buyer's eBay message.  # noqa: E501

        :param message: The message of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def order_id(self):
        """Gets the order_id of this ItemResponses.  # noqa: E501

        The unique identifier of the eBay order that the line item belongs to.  # noqa: E501

        :return: The order_id of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ItemResponses.

        The unique identifier of the eBay order that the line item belongs to.  # noqa: E501

        :param order_id: The order_id of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def order_line_item(self):
        """Gets the order_line_item of this ItemResponses.  # noqa: E501

        The unique identifier of an eBay order line item.  # noqa: E501

        :return: The order_line_item of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._order_line_item

    @order_line_item.setter
    def order_line_item(self, order_line_item):
        """Sets the order_line_item of this ItemResponses.

        The unique identifier of an eBay order line item.  # noqa: E501

        :param order_line_item: The order_line_item of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._order_line_item = order_line_item

    @property
    def payment_date(self):
        """Gets the payment_date of this ItemResponses.  # noqa: E501

        The date and time that the payment was received by the seller. This timestamp is returned in ISO 8601 format, which uses the 24-hour Universal Coordinated Time (UTC) clock.  # noqa: E501

        :return: The payment_date of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._payment_date

    @payment_date.setter
    def payment_date(self, payment_date):
        """Sets the payment_date of this ItemResponses.

        The date and time that the payment was received by the seller. This timestamp is returned in ISO 8601 format, which uses the 24-hour Universal Coordinated Time (UTC) clock.  # noqa: E501

        :param payment_date: The payment_date of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._payment_date = payment_date

    @property
    def pay_pal_email(self):
        """Gets the pay_pal_email of this ItemResponses.  # noqa: E501

        The buyer's PayPal email address.  # noqa: E501

        :return: The pay_pal_email of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._pay_pal_email

    @pay_pal_email.setter
    def pay_pal_email(self, pay_pal_email):
        """Sets the pay_pal_email of this ItemResponses.

        The buyer's PayPal email address.  # noqa: E501

        :param pay_pal_email: The pay_pal_email of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._pay_pal_email = pay_pal_email

    @property
    def pay_pal_message(self):
        """Gets the pay_pal_message of this ItemResponses.  # noqa: E501

        The buyer's PayPal message  # noqa: E501

        :return: The pay_pal_message of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._pay_pal_message

    @pay_pal_message.setter
    def pay_pal_message(self, pay_pal_message):
        """Sets the pay_pal_message of this ItemResponses.

        The buyer's PayPal message  # noqa: E501

        :param pay_pal_message: The pay_pal_message of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._pay_pal_message = pay_pal_message

    @property
    def posted_quantity(self):
        """Gets the posted_quantity of this ItemResponses.  # noqa: E501

        The quantity of the line item shipped with the package.  # noqa: E501

        :return: The posted_quantity of this ItemResponses.  # noqa: E501
        :rtype: int
        """
        return self._posted_quantity

    @posted_quantity.setter
    def posted_quantity(self, posted_quantity):
        """Sets the posted_quantity of this ItemResponses.

        The quantity of the line item shipped with the package.  # noqa: E501

        :param posted_quantity: The posted_quantity of this ItemResponses.  # noqa: E501
        :type: int
        """

        self._posted_quantity = posted_quantity

    @property
    def site_id(self):
        """Gets the site_id of this ItemResponses.  # noqa: E501

        The unique identifier of the eBay site in which the order occurred.  # noqa: E501

        :return: The site_id of this ItemResponses.  # noqa: E501
        :rtype: int
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this ItemResponses.

        The unique identifier of the eBay site in which the order occurred.  # noqa: E501

        :param site_id: The site_id of this ItemResponses.  # noqa: E501
        :type: int
        """

        self._site_id = site_id

    @property
    def sku(self):
        """Gets the sku of this ItemResponses.  # noqa: E501


        :return: The sku of this ItemResponses.  # noqa: E501
        :rtype: SkuRequest
        """
        return self._sku

    @sku.setter
    def sku(self, sku):
        """Sets the sku of this ItemResponses.


        :param sku: The sku of this ItemResponses.  # noqa: E501
        :type: SkuRequest
        """

        self._sku = sku

    @property
    def sold_date(self):
        """Gets the sold_date of this ItemResponses.  # noqa: E501

        The date the item was sold.  # noqa: E501

        :return: The sold_date of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._sold_date

    @sold_date.setter
    def sold_date(self, sold_date):
        """Sets the sold_date of this ItemResponses.

        The date the item was sold.  # noqa: E501

        :param sold_date: The sold_date of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._sold_date = sold_date

    @property
    def sold_price(self):
        """Gets the sold_price of this ItemResponses.  # noqa: E501


        :return: The sold_price of this ItemResponses.  # noqa: E501
        :rtype: Amount
        """
        return self._sold_price

    @sold_price.setter
    def sold_price(self, sold_price):
        """Sets the sold_price of this ItemResponses.


        :param sold_price: The sold_price of this ItemResponses.  # noqa: E501
        :type: Amount
        """

        self._sold_price = sold_price

    @property
    def sold_quantity(self):
        """Gets the sold_quantity of this ItemResponses.  # noqa: E501

        The quantity of the line item that was sold.  # noqa: E501

        :return: The sold_quantity of this ItemResponses.  # noqa: E501
        :rtype: int
        """
        return self._sold_quantity

    @sold_quantity.setter
    def sold_quantity(self, sold_quantity):
        """Sets the sold_quantity of this ItemResponses.

        The quantity of the line item that was sold.  # noqa: E501

        :param sold_quantity: The sold_quantity of this ItemResponses.  # noqa: E501
        :type: int
        """

        self._sold_quantity = sold_quantity

    @property
    def transaction_id(self):
        """Gets the transaction_id of this ItemResponses.  # noqa: E501

        The unique identifier of the eBay transaction.  # noqa: E501

        :return: The transaction_id of this ItemResponses.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this ItemResponses.

        The unique identifier of the eBay transaction.  # noqa: E501

        :param transaction_id: The transaction_id of this ItemResponses.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemResponses, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemResponses):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LocalListingDistance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'distances': 'list[int]',
        'distance_type': 'str'
    }

    attribute_map = {
        'distances': 'distances',
        'distance_type': 'distanceType'
    }

    def __init__(self, distances=None, distance_type=None):  # noqa: E501
        """LocalListingDistance - a model defined in Swagger"""  # noqa: E501
        self._distances = None
        self._distance_type = None
        self.discriminator = None
        if distances is not None:
            self.distances = distances
        if distance_type is not None:
            self.distance_type = distance_type

    @property
    def distances(self):
        """Gets the distances of this LocalListingDistance.  # noqa: E501

        This array indicates the radius (in miles) of the selling area for Local Market Vehicle listings.  # noqa: E501

        :return: The distances of this LocalListingDistance.  # noqa: E501
        :rtype: list[int]
        """
        return self._distances

    @distances.setter
    def distances(self, distances):
        """Sets the distances of this LocalListingDistance.

        This array indicates the radius (in miles) of the selling area for Local Market Vehicle listings.  # noqa: E501

        :param distances: The distances of this LocalListingDistance.  # noqa: E501
        :type: list[int]
        """

        self._distances = distances

    @property
    def distance_type(self):
        """Gets the distance_type of this LocalListingDistance.  # noqa: E501

        This enumerated value indicates the type of local listing distances, such as non-subscription or regular, for items listed by sellers. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:DistanceType'>eBay API documentation</a>  # noqa: E501

        :return: The distance_type of this LocalListingDistance.  # noqa: E501
        :rtype: str
        """
        return self._distance_type

    @distance_type.setter
    def distance_type(self, distance_type):
        """Sets the distance_type of this LocalListingDistance.

        This enumerated value indicates the type of local listing distances, such as non-subscription or regular, for items listed by sellers. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:DistanceType'>eBay API documentation</a>  # noqa: E501

        :param distance_type: The distance_type of this LocalListingDistance.  # noqa: E501
        :type: str
        """

        self._distance_type = distance_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocalListingDistance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocalListingDistance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SiteVisibilityPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'str',
        'category_tree_id': 'str',
        'cross_border_trade_australia_enabled': 'bool',
        'cross_border_trade_gb_enabled': 'bool',
        'cross_border_trade_north_america_enabled': 'bool'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'cross_border_trade_australia_enabled': 'crossBorderTradeAustraliaEnabled',
        'cross_border_trade_gb_enabled': 'crossBorderTradeGBEnabled',
        'cross_border_trade_north_america_enabled': 'crossBorderTradeNorthAmericaEnabled'
    }

    def __init__(self, category_id=None, category_tree_id=None, cross_border_trade_australia_enabled=None, cross_border_trade_gb_enabled=None, cross_border_trade_north_america_enabled=None):  # noqa: E501
        """SiteVisibilityPolicy - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_tree_id = None
        self._cross_border_trade_australia_enabled = None
        self._cross_border_trade_gb_enabled = None
        self._cross_border_trade_north_america_enabled = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if cross_border_trade_australia_enabled is not None:
            self.cross_border_trade_australia_enabled = cross_border_trade_australia_enabled
        if cross_border_trade_gb_enabled is not None:
            self.cross_border_trade_gb_enabled = cross_border_trade_gb_enabled
        if cross_border_trade_north_america_enabled is not None:
            self.cross_border_trade_north_america_enabled = cross_border_trade_north_america_enabled

    @property
    def category_id(self):
        """Gets the category_id of this SiteVisibilityPolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this SiteVisibilityPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this SiteVisibilityPolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this SiteVisibilityPolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this SiteVisibilityPolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this SiteVisibilityPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this SiteVisibilityPolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this SiteVisibilityPolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def cross_border_trade_australia_enabled(self):
        """Gets the cross_border_trade_australia_enabled of this SiteVisibilityPolicy.  # noqa: E501

        If <code>true</code>, the category supports specifying that listings of a seller on the UK marketplace can pass in Australia as a value in a <CrossBorderTrade> field to expose that item on the eBay Australia site (ebay.com.au). For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.  # noqa: E501

        :return: The cross_border_trade_australia_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._cross_border_trade_australia_enabled

    @cross_border_trade_australia_enabled.setter
    def cross_border_trade_australia_enabled(self, cross_border_trade_australia_enabled):
        """Sets the cross_border_trade_australia_enabled of this SiteVisibilityPolicy.

        If <code>true</code>, the category supports specifying that listings of a seller on the UK marketplace can pass in Australia as a value in a <CrossBorderTrade> field to expose that item on the eBay Australia site (ebay.com.au). For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.  # noqa: E501

        :param cross_border_trade_australia_enabled: The cross_border_trade_australia_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :type: bool
        """

        self._cross_border_trade_australia_enabled = cross_border_trade_australia_enabled

    @property
    def cross_border_trade_gb_enabled(self):
        """Gets the cross_border_trade_gb_enabled of this SiteVisibilityPolicy.  # noqa: E501

        If <code>true</code>, the category supports specifying that listings of a seller on the US or Canada merketplaces can pass in UK as a value in a <CrossBorderTrade> field to expose that item on the eBay UK (ebay.co.uk) and eBay IE (ebay.ie) sites. For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.  # noqa: E501

        :return: The cross_border_trade_gb_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._cross_border_trade_gb_enabled

    @cross_border_trade_gb_enabled.setter
    def cross_border_trade_gb_enabled(self, cross_border_trade_gb_enabled):
        """Sets the cross_border_trade_gb_enabled of this SiteVisibilityPolicy.

        If <code>true</code>, the category supports specifying that listings of a seller on the US or Canada merketplaces can pass in UK as a value in a <CrossBorderTrade> field to expose that item on the eBay UK (ebay.co.uk) and eBay IE (ebay.ie) sites. For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.  # noqa: E501

        :param cross_border_trade_gb_enabled: The cross_border_trade_gb_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :type: bool
        """

        self._cross_border_trade_gb_enabled = cross_border_trade_gb_enabled

    @property
    def cross_border_trade_north_america_enabled(self):
        """Gets the cross_border_trade_north_america_enabled of this SiteVisibilityPolicy.  # noqa: E501

        If <code>true</code>, the category supports specifying that listings of a seller on the US or Canada merketplaces can pass in North America as a value in a <CrossBorderTrade> field to expose that item on the eBay US (ebay.com) and eBay Canada (ebay.ca) sites (English). For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.   # noqa: E501

        :return: The cross_border_trade_north_america_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._cross_border_trade_north_america_enabled

    @cross_border_trade_north_america_enabled.setter
    def cross_border_trade_north_america_enabled(self, cross_border_trade_north_america_enabled):
        """Sets the cross_border_trade_north_america_enabled of this SiteVisibilityPolicy.

        If <code>true</code>, the category supports specifying that listings of a seller on the US or Canada merketplaces can pass in North America as a value in a <CrossBorderTrade> field to expose that item on the eBay US (ebay.com) and eBay Canada (ebay.ca) sites (English). For more information, see <a href=\"/api-docs/user-guides/static/trading-user-guide/cross-border-trading.html\"  target=\"_blank\">Cross-border trading</a>.   # noqa: E501

        :param cross_border_trade_north_america_enabled: The cross_border_trade_north_america_enabled of this SiteVisibilityPolicy.  # noqa: E501
        :type: bool
        """

        self._cross_border_trade_north_america_enabled = cross_border_trade_north_america_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SiteVisibilityPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SiteVisibilityPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deal API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units. For information on how to obtain access to this API in production, see the <a href=\"/../api-docs/buy/static/buy-requirements.html\" target=\"_blank\">Buy APIs Requirements</a>.</span><br /><br />This API allows third-party developers to search for and retrieve details about eBay deals and events, as well as the items associated with those deals and events.  # noqa: E501

    OpenAPI spec version: v1.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Coupon(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'redemption_code': 'str',
        'terms': 'Terms'
    }

    attribute_map = {
        'redemption_code': 'redemptionCode',
        'terms': 'terms'
    }

    def __init__(self, redemption_code=None, terms=None):  # noqa: E501
        """Coupon - a model defined in Swagger"""  # noqa: E501
        self._redemption_code = None
        self._terms = None
        self.discriminator = None
        if redemption_code is not None:
            self.redemption_code = redemption_code
        if terms is not None:
            self.terms = terms

    @property
    def redemption_code(self):
        """Gets the redemption_code of this Coupon.  # noqa: E501

        The coupon code.  # noqa: E501

        :return: The redemption_code of this Coupon.  # noqa: E501
        :rtype: str
        """
        return self._redemption_code

    @redemption_code.setter
    def redemption_code(self, redemption_code):
        """Sets the redemption_code of this Coupon.

        The coupon code.  # noqa: E501

        :param redemption_code: The redemption_code of this Coupon.  # noqa: E501
        :type: str
        """

        self._redemption_code = redemption_code

    @property
    def terms(self):
        """Gets the terms of this Coupon.  # noqa: E501


        :return: The terms of this Coupon.  # noqa: E501
        :rtype: Terms
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """Sets the terms of this Coupon.


        :param terms: The terms of this Coupon.  # noqa: E501
        :type: Terms
        """

        self._terms = terms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Coupon, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Coupon):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ClassifiedAdPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ad_format_enabled': 'str',
        'category_id': 'str',
        'category_tree_id': 'str',
        'classified_ad_auto_accept_enabled': 'bool',
        'classified_ad_auto_decline_enabled': 'bool',
        'classified_ad_best_offer_enabled': 'str',
        'classified_ad_company_name_enabled': 'bool',
        'classified_ad_contact_by_address_enabled': 'bool',
        'classified_ad_contact_by_email_enabled': 'bool',
        'classified_ad_contact_by_phone_enabled': 'bool',
        'classified_ad_counter_offer_enabled': 'bool',
        'classified_ad_payment_method_enabled': 'str',
        'classified_ad_phone_count': 'int',
        'classified_ad_shipping_method_enabled': 'bool',
        'classified_ad_street_count': 'int',
        'seller_contact_details_enabled': 'bool'
    }

    attribute_map = {
        'ad_format_enabled': 'adFormatEnabled',
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'classified_ad_auto_accept_enabled': 'classifiedAdAutoAcceptEnabled',
        'classified_ad_auto_decline_enabled': 'classifiedAdAutoDeclineEnabled',
        'classified_ad_best_offer_enabled': 'classifiedAdBestOfferEnabled',
        'classified_ad_company_name_enabled': 'classifiedAdCompanyNameEnabled',
        'classified_ad_contact_by_address_enabled': 'classifiedAdContactByAddressEnabled',
        'classified_ad_contact_by_email_enabled': 'classifiedAdContactByEmailEnabled',
        'classified_ad_contact_by_phone_enabled': 'classifiedAdContactByPhoneEnabled',
        'classified_ad_counter_offer_enabled': 'classifiedAdCounterOfferEnabled',
        'classified_ad_payment_method_enabled': 'classifiedAdPaymentMethodEnabled',
        'classified_ad_phone_count': 'classifiedAdPhoneCount',
        'classified_ad_shipping_method_enabled': 'classifiedAdShippingMethodEnabled',
        'classified_ad_street_count': 'classifiedAdStreetCount',
        'seller_contact_details_enabled': 'sellerContactDetailsEnabled'
    }

    def __init__(self, ad_format_enabled=None, category_id=None, category_tree_id=None, classified_ad_auto_accept_enabled=None, classified_ad_auto_decline_enabled=None, classified_ad_best_offer_enabled=None, classified_ad_company_name_enabled=None, classified_ad_contact_by_address_enabled=None, classified_ad_contact_by_email_enabled=None, classified_ad_contact_by_phone_enabled=None, classified_ad_counter_offer_enabled=None, classified_ad_payment_method_enabled=None, classified_ad_phone_count=None, classified_ad_shipping_method_enabled=None, classified_ad_street_count=None, seller_contact_details_enabled=None):  # noqa: E501
        """ClassifiedAdPolicy - a model defined in Swagger"""  # noqa: E501
        self._ad_format_enabled = None
        self._category_id = None
        self._category_tree_id = None
        self._classified_ad_auto_accept_enabled = None
        self._classified_ad_auto_decline_enabled = None
        self._classified_ad_best_offer_enabled = None
        self._classified_ad_company_name_enabled = None
        self._classified_ad_contact_by_address_enabled = None
        self._classified_ad_contact_by_email_enabled = None
        self._classified_ad_contact_by_phone_enabled = None
        self._classified_ad_counter_offer_enabled = None
        self._classified_ad_payment_method_enabled = None
        self._classified_ad_phone_count = None
        self._classified_ad_shipping_method_enabled = None
        self._classified_ad_street_count = None
        self._seller_contact_details_enabled = None
        self.discriminator = None
        if ad_format_enabled is not None:
            self.ad_format_enabled = ad_format_enabled
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if classified_ad_auto_accept_enabled is not None:
            self.classified_ad_auto_accept_enabled = classified_ad_auto_accept_enabled
        if classified_ad_auto_decline_enabled is not None:
            self.classified_ad_auto_decline_enabled = classified_ad_auto_decline_enabled
        if classified_ad_best_offer_enabled is not None:
            self.classified_ad_best_offer_enabled = classified_ad_best_offer_enabled
        if classified_ad_company_name_enabled is not None:
            self.classified_ad_company_name_enabled = classified_ad_company_name_enabled
        if classified_ad_contact_by_address_enabled is not None:
            self.classified_ad_contact_by_address_enabled = classified_ad_contact_by_address_enabled
        if classified_ad_contact_by_email_enabled is not None:
            self.classified_ad_contact_by_email_enabled = classified_ad_contact_by_email_enabled
        if classified_ad_contact_by_phone_enabled is not None:
            self.classified_ad_contact_by_phone_enabled = classified_ad_contact_by_phone_enabled
        if classified_ad_counter_offer_enabled is not None:
            self.classified_ad_counter_offer_enabled = classified_ad_counter_offer_enabled
        if classified_ad_payment_method_enabled is not None:
            self.classified_ad_payment_method_enabled = classified_ad_payment_method_enabled
        if classified_ad_phone_count is not None:
            self.classified_ad_phone_count = classified_ad_phone_count
        if classified_ad_shipping_method_enabled is not None:
            self.classified_ad_shipping_method_enabled = classified_ad_shipping_method_enabled
        if classified_ad_street_count is not None:
            self.classified_ad_street_count = classified_ad_street_count
        if seller_contact_details_enabled is not None:
            self.seller_contact_details_enabled = seller_contact_details_enabled

    @property
    def ad_format_enabled(self):
        """Gets the ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates the type or status of available Classified Ad formats for this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._ad_format_enabled

    @ad_format_enabled.setter
    def ad_format_enabled(self, ad_format_enabled):
        """Sets the ad_format_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates the type or status of available Classified Ad formats for this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param ad_format_enabled: The ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._ad_format_enabled = ad_format_enabled

    @property
    def category_id(self):
        """Gets the category_id of this ClassifiedAdPolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ClassifiedAdPolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this ClassifiedAdPolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this ClassifiedAdPolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def classified_ad_auto_accept_enabled(self):
        """Gets the classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether the category supports the Best Offer Automatic Accept feature for Classified Ad listings.  # noqa: E501

        :return: The classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_auto_accept_enabled

    @classified_ad_auto_accept_enabled.setter
    def classified_ad_auto_accept_enabled(self, classified_ad_auto_accept_enabled):
        """Sets the classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.

        Indicates whether the category supports the Best Offer Automatic Accept feature for Classified Ad listings.  # noqa: E501

        :param classified_ad_auto_accept_enabled: The classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_auto_accept_enabled = classified_ad_auto_accept_enabled

    @property
    def classified_ad_auto_decline_enabled(self):
        """Gets the classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether the category supports the Best Offer Automatic Reject feature for Classified Ad listings.  # noqa: E501

        :return: The classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_auto_decline_enabled

    @classified_ad_auto_decline_enabled.setter
    def classified_ad_auto_decline_enabled(self, classified_ad_auto_decline_enabled):
        """Sets the classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.

        Indicates whether the category supports the Best Offer Automatic Reject feature for Classified Ad listings.  # noqa: E501

        :param classified_ad_auto_decline_enabled: The classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_auto_decline_enabled = classified_ad_auto_decline_enabled

    @property
    def classified_ad_best_offer_enabled(self):
        """Gets the classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates if Best Offer is enabled, disabled, or required for Classified Ad listings in this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._classified_ad_best_offer_enabled

    @classified_ad_best_offer_enabled.setter
    def classified_ad_best_offer_enabled(self, classified_ad_best_offer_enabled):
        """Sets the classified_ad_best_offer_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates if Best Offer is enabled, disabled, or required for Classified Ad listings in this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param classified_ad_best_offer_enabled: The classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._classified_ad_best_offer_enabled = classified_ad_best_offer_enabled

    @property
    def classified_ad_company_name_enabled(self):
        """Gets the classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports including a company name in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :return: The classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_company_name_enabled

    @classified_ad_company_name_enabled.setter
    def classified_ad_company_name_enabled(self, classified_ad_company_name_enabled):
        """Sets the classified_ad_company_name_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports including a company name in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :param classified_ad_company_name_enabled: The classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_company_name_enabled = classified_ad_company_name_enabled

    @property
    def classified_ad_contact_by_address_enabled(self):
        """Gets the classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports including an address in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :return: The classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_address_enabled

    @classified_ad_contact_by_address_enabled.setter
    def classified_ad_contact_by_address_enabled(self, classified_ad_contact_by_address_enabled):
        """Sets the classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports including an address in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :param classified_ad_contact_by_address_enabled: The classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_address_enabled = classified_ad_contact_by_address_enabled

    @property
    def classified_ad_contact_by_email_enabled(self):
        """Gets the classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether most categories support including an email address in the seller's contact information.  # noqa: E501

        :return: The classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_email_enabled

    @classified_ad_contact_by_email_enabled.setter
    def classified_ad_contact_by_email_enabled(self, classified_ad_contact_by_email_enabled):
        """Sets the classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.

        Indicates whether most categories support including an email address in the seller's contact information.  # noqa: E501

        :param classified_ad_contact_by_email_enabled: The classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_email_enabled = classified_ad_contact_by_email_enabled

    @property
    def classified_ad_contact_by_phone_enabled(self):
        """Gets the classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether most categories support including a phone number in the seller's contact information.  # noqa: E501

        :return: The classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_phone_enabled

    @classified_ad_contact_by_phone_enabled.setter
    def classified_ad_contact_by_phone_enabled(self, classified_ad_contact_by_phone_enabled):
        """Sets the classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.

        Indicates whether most categories support including a phone number in the seller's contact information.  # noqa: E501

        :param classified_ad_contact_by_phone_enabled: The classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_phone_enabled = classified_ad_contact_by_phone_enabled

    @property
    def classified_ad_counter_offer_enabled(self):
        """Gets the classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether counter offers are allowed on Best offers for the category.  # noqa: E501

        :return: The classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_counter_offer_enabled

    @classified_ad_counter_offer_enabled.setter
    def classified_ad_counter_offer_enabled(self, classified_ad_counter_offer_enabled):
        """Sets the classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.

        Indicates whether counter offers are allowed on Best offers for the category.  # noqa: E501

        :param classified_ad_counter_offer_enabled: The classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_counter_offer_enabled = classified_ad_counter_offer_enabled

    @property
    def classified_ad_payment_method_enabled(self):
        """Gets the classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates support for the payment method being displayed to the user for the category. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._classified_ad_payment_method_enabled

    @classified_ad_payment_method_enabled.setter
    def classified_ad_payment_method_enabled(self, classified_ad_payment_method_enabled):
        """Sets the classified_ad_payment_method_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates support for the payment method being displayed to the user for the category. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param classified_ad_payment_method_enabled: The classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._classified_ad_payment_method_enabled = classified_ad_payment_method_enabled

    @property
    def classified_ad_phone_count(self):
        """Gets the classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501

        Indicates how many contact phone numbers can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :return: The classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: int
        """
        return self._classified_ad_phone_count

    @classified_ad_phone_count.setter
    def classified_ad_phone_count(self, classified_ad_phone_count):
        """Sets the classified_ad_phone_count of this ClassifiedAdPolicy.

        Indicates how many contact phone numbers can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :param classified_ad_phone_count: The classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501
        :type: int
        """

        self._classified_ad_phone_count = classified_ad_phone_count

    @property
    def classified_ad_shipping_method_enabled(self):
        """Gets the classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates if shipping methods can be specified and displayed in the <b>View Item</b> page for the category.  # noqa: E501

        :return: The classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_shipping_method_enabled

    @classified_ad_shipping_method_enabled.setter
    def classified_ad_shipping_method_enabled(self, classified_ad_shipping_method_enabled):
        """Sets the classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.

        Indicates if shipping methods can be specified and displayed in the <b>View Item</b> page for the category.  # noqa: E501

        :param classified_ad_shipping_method_enabled: The classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_shipping_method_enabled = classified_ad_shipping_method_enabled

    @property
    def classified_ad_street_count(self):
        """Gets the classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501

        Indicates how many street addresses can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :return: The classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: int
        """
        return self._classified_ad_street_count

    @classified_ad_street_count.setter
    def classified_ad_street_count(self, classified_ad_street_count):
        """Sets the classified_ad_street_count of this ClassifiedAdPolicy.

        Indicates how many street addresses can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :param classified_ad_street_count: The classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501
        :type: int
        """

        self._classified_ad_street_count = classified_ad_street_count

    @property
    def seller_contact_details_enabled(self):
        """Gets the seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports seller-level contact information for Classified Ad listings.  # noqa: E501

        :return: The seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._seller_contact_details_enabled

    @seller_contact_details_enabled.setter
    def seller_contact_details_enabled(self, seller_contact_details_enabled):
        """Sets the seller_contact_details_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports seller-level contact information for Classified Ad listings.  # noqa: E501

        :param seller_contact_details_enabled: The seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._seller_contact_details_enabled = seller_contact_details_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClassifiedAdPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassifiedAdPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Inventory API

    The Inventory API is used to create and manage inventory, and then to publish and manage this inventory on an eBay marketplace. There are also methods in this API that will convert eligible, active eBay listings into the Inventory API model.  # noqa: E501

    OpenAPI spec version: 1.18.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LocationAvailabilityDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'merchant_location_key': 'str'
    }

    attribute_map = {
        'merchant_location_key': 'merchantLocationKey'
    }

    def __init__(self, merchant_location_key=None):  # noqa: E501
        """LocationAvailabilityDetails - a model defined in Swagger"""  # noqa: E501
        self._merchant_location_key = None
        self.discriminator = None
        if merchant_location_key is not None:
            self.merchant_location_key = merchant_location_key

    @property
    def merchant_location_key(self):
        """Gets the merchant_location_key of this LocationAvailabilityDetails.  # noqa: E501

        The unique identifier of a seller’s fulfillment center location where inventory is available for the item or item variation.<br><br><span class=\"tablenote\"><b>Note:</b> When creating a location mapping using the <b>createOrReplaceSkuLocationMapping</b> method, the value entered in this field <b>must</b> be associated with a location with the <code>FULFILLMENT_CENTER</code> location type, or an error will occur. Sellers can check the <a href=\"/api-docs/sell/inventory/resources/location/methods/getInventoryLocations#response.locations.locationTypes\" target=\"_blank\">locationTypes</a> array in the response of the <a href=\"/api-docs/sell/inventory/resources/location/methods/getInventoryLocations\" target=\"_blank\">getInventoryLocations</a> method to see if their location has a value of <code>FULFILLMENT_CENTER</code>.</span>  # noqa: E501

        :return: The merchant_location_key of this LocationAvailabilityDetails.  # noqa: E501
        :rtype: str
        """
        return self._merchant_location_key

    @merchant_location_key.setter
    def merchant_location_key(self, merchant_location_key):
        """Sets the merchant_location_key of this LocationAvailabilityDetails.

        The unique identifier of a seller’s fulfillment center location where inventory is available for the item or item variation.<br><br><span class=\"tablenote\"><b>Note:</b> When creating a location mapping using the <b>createOrReplaceSkuLocationMapping</b> method, the value entered in this field <b>must</b> be associated with a location with the <code>FULFILLMENT_CENTER</code> location type, or an error will occur. Sellers can check the <a href=\"/api-docs/sell/inventory/resources/location/methods/getInventoryLocations#response.locations.locationTypes\" target=\"_blank\">locationTypes</a> array in the response of the <a href=\"/api-docs/sell/inventory/resources/location/methods/getInventoryLocations\" target=\"_blank\">getInventoryLocations</a> method to see if their location has a value of <code>FULFILLMENT_CENTER</code>.</span>  # noqa: E501

        :param merchant_location_key: The merchant_location_key of this LocationAvailabilityDetails.  # noqa: E501
        :type: str
        """

        self._merchant_location_key = merchant_location_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationAvailabilityDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationAvailabilityDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetActualCostResponsesData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'actual_weight': 'float',
        'amount': 'Amount',
        'billing_time': 'str',
        'charge_mode': 'str',
        'charge_weight': 'float',
        'cost_type': 'str',
        'message': 'str',
        'remark': 'str',
        'result_code': 'str',
        'size': 'str',
        'tracking_number': 'str'
    }

    attribute_map = {
        'actual_weight': 'actualWeight',
        'amount': 'amount',
        'billing_time': 'billingTime',
        'charge_mode': 'chargeMode',
        'charge_weight': 'chargeWeight',
        'cost_type': 'costType',
        'message': 'message',
        'remark': 'remark',
        'result_code': 'resultCode',
        'size': 'size',
        'tracking_number': 'trackingNumber'
    }

    def __init__(self, actual_weight=None, amount=None, billing_time=None, charge_mode=None, charge_weight=None, cost_type=None, message=None, remark=None, result_code=None, size=None, tracking_number=None):  # noqa: E501
        """GetActualCostResponsesData - a model defined in Swagger"""  # noqa: E501
        self._actual_weight = None
        self._amount = None
        self._billing_time = None
        self._charge_mode = None
        self._charge_weight = None
        self._cost_type = None
        self._message = None
        self._remark = None
        self._result_code = None
        self._size = None
        self._tracking_number = None
        self.discriminator = None
        if actual_weight is not None:
            self.actual_weight = actual_weight
        if amount is not None:
            self.amount = amount
        if billing_time is not None:
            self.billing_time = billing_time
        if charge_mode is not None:
            self.charge_mode = charge_mode
        if charge_weight is not None:
            self.charge_weight = charge_weight
        if cost_type is not None:
            self.cost_type = cost_type
        if message is not None:
            self.message = message
        if remark is not None:
            self.remark = remark
        if result_code is not None:
            self.result_code = result_code
        if size is not None:
            self.size = size
        if tracking_number is not None:
            self.tracking_number = tracking_number

    @property
    def actual_weight(self):
        """Gets the actual_weight of this GetActualCostResponsesData.  # noqa: E501

        The actual weight of the package in grams.  # noqa: E501

        :return: The actual_weight of this GetActualCostResponsesData.  # noqa: E501
        :rtype: float
        """
        return self._actual_weight

    @actual_weight.setter
    def actual_weight(self, actual_weight):
        """Sets the actual_weight of this GetActualCostResponsesData.

        The actual weight of the package in grams.  # noqa: E501

        :param actual_weight: The actual_weight of this GetActualCostResponsesData.  # noqa: E501
        :type: float
        """

        self._actual_weight = actual_weight

    @property
    def amount(self):
        """Gets the amount of this GetActualCostResponsesData.  # noqa: E501


        :return: The amount of this GetActualCostResponsesData.  # noqa: E501
        :rtype: Amount
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this GetActualCostResponsesData.


        :param amount: The amount of this GetActualCostResponsesData.  # noqa: E501
        :type: Amount
        """

        self._amount = amount

    @property
    def billing_time(self):
        """Gets the billing_time of this GetActualCostResponsesData.  # noqa: E501

        The time the seller was charged for the actual cost of the package in UTC format.  # noqa: E501

        :return: The billing_time of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._billing_time

    @billing_time.setter
    def billing_time(self, billing_time):
        """Sets the billing_time of this GetActualCostResponsesData.

        The time the seller was charged for the actual cost of the package in UTC format.  # noqa: E501

        :param billing_time: The billing_time of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._billing_time = billing_time

    @property
    def charge_mode(self):
        """Gets the charge_mode of this GetActualCostResponsesData.  # noqa: E501

        The two-digit charge mode for the package.<br><br><b>Valid values</b>:<ul><li><code>01</code>: Actual weight</li><li><code>02</code>: Additional dimension weight</li><li><code>03</code>: Charged by lite mode</li></ul>  # noqa: E501

        :return: The charge_mode of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._charge_mode

    @charge_mode.setter
    def charge_mode(self, charge_mode):
        """Sets the charge_mode of this GetActualCostResponsesData.

        The two-digit charge mode for the package.<br><br><b>Valid values</b>:<ul><li><code>01</code>: Actual weight</li><li><code>02</code>: Additional dimension weight</li><li><code>03</code>: Charged by lite mode</li></ul>  # noqa: E501

        :param charge_mode: The charge_mode of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._charge_mode = charge_mode

    @property
    def charge_weight(self):
        """Gets the charge_weight of this GetActualCostResponsesData.  # noqa: E501

        The weight, in grams, charged for when shipping the package.  # noqa: E501

        :return: The charge_weight of this GetActualCostResponsesData.  # noqa: E501
        :rtype: float
        """
        return self._charge_weight

    @charge_weight.setter
    def charge_weight(self, charge_weight):
        """Sets the charge_weight of this GetActualCostResponsesData.

        The weight, in grams, charged for when shipping the package.  # noqa: E501

        :param charge_weight: The charge_weight of this GetActualCostResponsesData.  # noqa: E501
        :type: float
        """

        self._charge_weight = charge_weight

    @property
    def cost_type(self):
        """Gets the cost_type of this GetActualCostResponsesData.  # noqa: E501

        The two-digit cost type of the package. This field indicates any fees associated with the package.<br><br>The following values are the typical cost types returned through this field. If an undocumented cost type is returned, check the logistic provider's website for the latest values:<br><ul><li><code>01</code>: Shipping fee</li><li><code>02</code>: Domestic</li><li><code>03</code>: Return fee</li><li><code>04</code>: Domestic burning fee</li><li><code>05</code>: Custom collected fee</li><li><code>06</code>: Weight gap fee</li><li><code>07</code>: Duplication compensation</li></ul>  # noqa: E501

        :return: The cost_type of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._cost_type

    @cost_type.setter
    def cost_type(self, cost_type):
        """Sets the cost_type of this GetActualCostResponsesData.

        The two-digit cost type of the package. This field indicates any fees associated with the package.<br><br>The following values are the typical cost types returned through this field. If an undocumented cost type is returned, check the logistic provider's website for the latest values:<br><ul><li><code>01</code>: Shipping fee</li><li><code>02</code>: Domestic</li><li><code>03</code>: Return fee</li><li><code>04</code>: Domestic burning fee</li><li><code>05</code>: Custom collected fee</li><li><code>06</code>: Weight gap fee</li><li><code>07</code>: Duplication compensation</li></ul>  # noqa: E501

        :param cost_type: The cost_type of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._cost_type = cost_type

    @property
    def message(self):
        """Gets the message of this GetActualCostResponsesData.  # noqa: E501

        A seller-defined message to the buyer regarding the transaction.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The message of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this GetActualCostResponsesData.

        A seller-defined message to the buyer regarding the transaction.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param message: The message of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def remark(self):
        """Gets the remark of this GetActualCostResponsesData.  # noqa: E501

        A remark to the seller themselves.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The remark of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this GetActualCostResponsesData.

        A remark to the seller themselves.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param remark: The remark of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def result_code(self):
        """Gets the result_code of this GetActualCostResponsesData.  # noqa: E501

        The result code associated with the call.<br><br>For example, a result code of <code>200</code> indicates that the call was a success.  # noqa: E501

        :return: The result_code of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._result_code

    @result_code.setter
    def result_code(self, result_code):
        """Sets the result_code of this GetActualCostResponsesData.

        The result code associated with the call.<br><br>For example, a result code of <code>200</code> indicates that the call was a success.  # noqa: E501

        :param result_code: The result_code of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._result_code = result_code

    @property
    def size(self):
        """Gets the size of this GetActualCostResponsesData.  # noqa: E501

        The size of the package in centimeters. This value is returned in Length*Width*Height format.  # noqa: E501

        :return: The size of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this GetActualCostResponsesData.

        The size of the package in centimeters. This value is returned in Length*Width*Height format.  # noqa: E501

        :param size: The size of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def tracking_number(self):
        """Gets the tracking_number of this GetActualCostResponsesData.  # noqa: E501

        The tracking number associated with the package.  # noqa: E501

        :return: The tracking_number of this GetActualCostResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._tracking_number

    @tracking_number.setter
    def tracking_number(self, tracking_number):
        """Sets the tracking_number of this GetActualCostResponsesData.

        The tracking number associated with the package.  # noqa: E501

        :param tracking_number: The tracking_number of this GetActualCostResponsesData.  # noqa: E501
        :type: str
        """

        self._tracking_number = tracking_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetActualCostResponsesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetActualCostResponsesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
